@@ -28,13 +28,13 @@ from argparse import ArgumentParser
 from gevent import monkey; monkey.patch_all()
 from gevent import sleep
 
-from .core import VERSION
+from . import __version__
 from .state import SlimtaState
 
 
 def parse_args():
     argparser = ArgumentParser(description='Configurable MTA based on the python-slimta libraries.')
-    argparser.add_argument('--version', action='version', version='%(prog)s '+VERSION)
+    argparser.add_argument('--version', action='version', version='%(prog)s '+__version__)
     argparser.add_argument('-c', '--config', metavar='FILE', default=None,
                     help='Specifies a configuration file to read. If not given, the default locations ($HOME/.slimta/slimta.conf, /etc/slimta/slimta.conf) are checked.')
     argparser.add_argument('-a', '--no-daemon', dest='attached', action='store_true',
@@ -49,7 +49,7 @@ def slimta():
     state = SlimtaState('slimta')
     state.load_config(*parse_args())
 
-    state.start_edges()
+    state.start_everything()
 
     state.setup_logging()
     state.redirect_streams()
@@ -110,7 +110,8 @@ def setup():
     if etc_dir is None:
         etc_dir = raw_input('Where should slimta config files be placed? [{0}] '.format(default_etc_dir))
         if not etc_dir:
-            etc_dir = os.path.expanduser(default_etc_dir)
+            etc_dir = default_etc_dir
+    etc_dir = os.path.expandvars(os.path.expanduser(etc_dir))
     try:
         os.makedirs(etc_dir, 0755)
     except OSError as (err, msg):
