@@ -145,6 +145,8 @@ class SlimtaState(object):
         setup_logging(settings)
 
     def _get_tls_options(self, tls_opts):
+        if not tls_opts:
+            return None
         tls_opts = dict(tls_opts).copy()
         certfile = tls_opts.pop('certfile', None)
         if certfile is not None:
@@ -203,7 +205,7 @@ class SlimtaState(object):
             new_relay = MxSmtpRelay(**kwargs)
         elif options.type == 'static':
             from slimta.relay.smtp.static import StaticSmtpRelay
-            from .helpers import fill_hostname_template
+            from .helpers import fill_hostname_template, get_relay_credentials
             kwargs = {}
             kwargs['host'] = options.host
             kwargs['port'] = options.get('port', 25)
@@ -215,11 +217,31 @@ class SlimtaState(object):
             kwargs['ehlo_as'] = fill_hostname_template(options.get('ehlo_as'))
             if 'tls' in options:
                 kwargs['tls'] = self._get_tls_options(options.tls)
+            if 'credentials' in options:
+                credentials = get_relay_credentials(options.get('credentials'))
+                kwargs['credentials'] = credentials
             new_relay = StaticSmtpRelay(**kwargs)
+        elif options.type == 'http':
+            from slimta.relay.http import HttpRelay
+            from .helpers import fill_hostname_template
+            kwargs = {}
+            kwargs['ehlo_as'] = fill_hostname_template(options.get('ehlo_as'))
+            kwargs['timeout'] = options.get('timeout', 60)
+            kwargs['idle_timeout'] = options.get('idle_timeout', 10)
+            if 'tls' in options:
+                kwargs['tls'] = self._get_tls_options(options.tls)
+            new_relay = HttpRelay(options.url, **kwargs)
+        elif options.type == 'blackhole':
+            from slimta.relay.blackhole import BlackholeRelay
+            new_relay = BlackholeRelay()
         elif options.type == 'maildrop':
-            from slimta.maildroprelay import MaildropRelay
-            executable = options.get('executable')
-            new_relay = MaildropRelay(executable=executable)
+            from slimta.piperelay import MaildropRelay
+            path = options.get('path')
+            new_relay = MaildropRelay(path)
+        elif options.type == 'dovecot':
+            from slimta.piperelay import DovecotRelay
+            path = options.get('path')
+            new_relay = DovecotRelay(path)
         elif options.type == 'custom':
             new_relay = self._load_from_custom(options)
         else:
@@ -235,13 +257,14 @@ class SlimtaState(object):
         from .helpers import add_queue_policies, build_backoff_function
         new_queue = None
         relay_name = options.get('relay')
-        relay = self._start_relay(relay_name)
+        relay = self._start_relay(relay_name) if relay_name else None
         if options.type == 'memory':
             from slimta.queue import Queue
             from slimta.queue.dict import DictStorage
             store = DictStorage()
             backoff = build_backoff_function(options.get('retry'))
             new_queue = Queue(store, relay, backoff=backoff)
+            new_queue.start()
         elif options.type == 'disk':
             from slimta.queue import Queue
             from slimta.diskstorage import DiskStorage
@@ -251,6 +274,27 @@ class SlimtaState(object):
             store = DiskStorage(env_dir, meta_dir, tmp_dir)
             backoff = build_backoff_function(options.get('retry'))
             new_queue = Queue(store, relay, backoff=backoff)
+            new_queue.start()
+        elif options.type == 'redis':
+            from slimta.queue import Queue
+            from slimta.redisstorage import RedisStorage
+            kwargs = {}
+            if 'host' in options:
+                kwargs['host'] = options.host
+            if 'port' in options:
+                kwargs['port'] = int(options.port)
+            if 'db' in options:
+                kwargs['db'] = int(options.db)
+            if 'password' in options:
+                kwargs['password'] = options.password
+            if 'socket_timeout' in options:
+                kwargs['socket_timeout'] = float(options.socket_timeout)
+            if 'prefix' in options:
+                kwargs['prefix'] = options.prefix
+            store = RedisStorage(**kwargs)
+            backoff = build_backoff_function(options.get('retry'))
+            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue.start()
         elif options.type == 'proxy':
             from slimta.queue.proxy import ProxyQueue
             new_queue = ProxyQueue(relay)
@@ -292,8 +336,7 @@ class SlimtaState(object):
             ip = options.listener.get('interface', '127.0.0.1')
             port = int(options.listener.get('port', 25))
             kwargs = {}
-            if options.get('tls'):
-                kwargs['tls'] = self._get_tls_options(options.tls)
+            kwargs['tls'] = self._get_tls_options(options.get('tls'))
             kwargs['tls_immediately'] = options.get('tls_immediately', False)
             kwargs['validator_class'] = build_smtpedge_validators(options)
             kwargs['auth_class'] = build_smtpedge_auth(options)
@@ -303,6 +346,19 @@ class SlimtaState(object):
             kwargs['hostname'] = fill_hostname_template(options.get('hostname'))
             new_edge = SmtpEdge((ip, port), queue, **kwargs)
             new_edge.start()
+        elif options.type == 'http':
+            from slimta.edge.wsgi import WsgiEdge
+            from .helpers import build_wsgiedge_validators
+            from .helpers import fill_hostname_template
+            hostname = fill_hostname_template(options.get('hostname'))
+            uri_pattern = options.get('uri')
+            validator_class = build_wsgiedge_validators(options)
+            new_edge = WsgiEdge(queue, hostname, validator_class, uri_pattern)
+            ip = options.listener.get('interface', '127.0.0.1')
+            port = int(options.listener.get('port', 8025))
+            tls = self._get_tls_options(options.get('tls'))
+            server = new_edge.build_server((ip, port), tls=tls)
+            server.start()
         elif options.type == 'custom':
             new_edge = self._load_from_custom(options, queue)
         else:
@@ -310,9 +366,17 @@ class SlimtaState(object):
         self.edges[name] = new_edge
         return new_edge
 
-    def start_edges(self):
-        for name, options in dict(self.cfg.edge).items():
-            self._start_edge(name, options)
+    def start_everything(self):
+        if 'relay' in self.cfg:
+            for name, options in dict(self.cfg.relay).items():
+                self._start_relay(name, options)
+
+        for name, options in dict(self.cfg.queue).items():
+            self._start_queue(name, options)
+
+        if 'edge' in self.cfg:
+            for name, options in dict(self.cfg.edge).items():
+                self._start_edge(name, options)
 
     def worker_loop(self):
         try:
